summaryrefslogtreecommitdiff
path: root/mp_minv_tab.c
diff options
context:
space:
mode:
authorTorbjorn Granlund <tege@gmplib.org>2008-11-21 11:31:46 +0100
committerTorbjorn Granlund <tege@gmplib.org>2008-11-21 11:31:46 +0100
commit4467b64b917916c1de0191dbc1ef8fd4492d7c58 (patch)
tree0a804eba70fe3dde63b1d172525818ae7e0f7537 /mp_minv_tab.c
parent3a1aa0402781d068164220a940d4278e24df0e1c (diff)
downloadgmp-4467b64b917916c1de0191dbc1ef8fd4492d7c58.tar.gz
Rename modlimb_invert to binvert_limb.
Diffstat (limited to 'mp_minv_tab.c')
-rw-r--r--mp_minv_tab.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/mp_minv_tab.c b/mp_minv_tab.c
index 9eb987513..a7f342b7c 100644
--- a/mp_minv_tab.c
+++ b/mp_minv_tab.c
@@ -1,4 +1,4 @@
/* A table of data supporting modlimb_invert().
THE CONTENTS OF THIS FILE ARE FOR INTERNAL USE AND MAY CHANGE
INCOMPATIBLY OR DISAPPEAR IN A FUTURE GNU MP RELEASE. */
@@ -25,10 +25,10 @@ along with the GNU MP Library. If not, see http://www.gnu.org/licenses/. */
#include "gmp-impl.h"
-/* modlimb_invert_table[i] is the multiplicative inverse of 2*i+1 mod 256,
- ie. (modlimb_invert_table[i] * (2*i+1)) % 256 == 1 */
+/* binvert_limb_table[i] is the multiplicative inverse of 2*i+1 mod 256,
+ ie. (binvert_limb_table[i] * (2*i+1)) % 256 == 1 */
-const unsigned char modlimb_invert_table[128] = {
+const unsigned char binvert_limb_table[128] = {
0x01, 0xAB, 0xCD, 0xB7, 0x39, 0xA3, 0xC5, 0xEF,
0xF1, 0x1B, 0x3D, 0xA7, 0x29, 0x13, 0x35, 0xDF,
0xE1, 0x8B, 0xAD, 0x97, 0x19, 0x83, 0xA5, 0xCF,
@@ -1,4 +1,4 @@
-/* A table of data supporting modlimb_invert().
+/* A table of data supporting binvert_limb().
THE CONTENTS OF THIS FILE ARE FOR INTERNAL USE AND MAY CHANGE
INCOMPATIBLY OR DISAPPEAR IN A FUTURE GNU MP RELEASE. */